| Title: | Normalized Laplacian Matrix and Laplacian Map |
|---|---|
| Description: | Constructs the normalized Laplacian matrix of a square matrix, returns the eigenvectors (singular vectors) and visualization of normalized Laplacian map. |
| Authors: | Tianhao Wu [aut, cre] |
| Maintainer: | Tianhao Wu <[email protected]> |
| License: | GNU General Public License version 2 |
| Version: | 1.0 |
| Built: | 2026-05-11 06:58:27 UTC |
| Source: | https://github.com/cran/matrixLaplacian |
Constructs the normalized Laplacian matrix of a square matrix, returns the eigenvectors (singular vectors) and visualization of normalized Laplacian map.
matrixLaplacian(A, plot2D=TRUE, plot3D=TRUE)matrixLaplacian(A, plot2D=TRUE, plot3D=TRUE)
A |
a numeric or complex matrix whose normalized Laplacian matrix is to be computed |
plot2D |
a logical value indicating whether a 2-D map should be plotted |
plot3D |
a logical value indicating whether a 3-D map should be plotted |
LaplacianMatrix |
the symmetric normalized Laplacian matrix |
eigenvector |
the eigenvectors of normalized Laplacian matrix, which are same as singular vectors |
#Create a square matrix A <- matrix(c(1:16), 4, 4) #Construct normalized Laplacian matrix and plot map m <- matrixLaplacian(A, plot2D=TRUE, plot3D=TRUE) #See the eigenvectors vector<-m$eigenvector#Create a square matrix A <- matrix(c(1:16), 4, 4) #Construct normalized Laplacian matrix and plot map m <- matrixLaplacian(A, plot2D=TRUE, plot3D=TRUE) #See the eigenvectors vector<-m$eigenvector